# Changelog

## [Unreleased][] (YYYY-MM-DD)

_No changes yet._

## [0.1.0][] (2026-01-19)

Initial release includes:

- `val.viz.schematic_diagram()` helper to showing data structure and visual diffs.
- Helper methods for PaCMAP and LocalMAP dimensional reduction.
- Langevitour visualisation for exploring high dimensional space.
- Basic Jupyter Scatter support for up to 1M participants, including animations.
- Import of Polis conversation data.
- Basic Polis v1 pipeline support.
- Added `val.tools.kmeans()`.
- Large reference datasets for Aufstehen political party consultation (33k participants) and the #ChileDesperto protest (3k).
- `val.viz.voter_vignette_widget()` for exploring data stories of random individuals.
- Comprehensive documentation website.
- Wrappers for various scanpy methods.

<!-- Links -->

[Unreleased]: https://github.com/patcon/valency-anndata/compare/v0.1.0...main
[0.1.0]: https://github.com/patcon/valency-anndata/releases/tag/v0.1.0
